/*
    SPDX-FileCopyrightText: 2016 Elvis Angelaccio <elvis.angelaccio@kde.org>

    SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "colorsettings.h"

ColorSettings::ColorSettings(QWidget *parent) : QWidget(parent)
{
    setupUi(this);
}
